#include <stdio.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <fcntl.h>

#define ADC_DEV        "/dev/at91_adc"
#define ADC_IOC_MAGIC   'j'
#define ADC_REQUEST 	_IOWR(ADC_IOC_MAGIC, 1, int)			//un-used atm
#define ADC_READ		_IOR(ADC_IOC_MAGIC, 2, int)
#define ADC_FREE		_IOWR(ADC_IOC_MAGIC, 3, int)

int adc_fd;

/************************************************************
 * open_adc:
 *     Open adc device
 *
 *   adc: the path point to adc device
 ***********************************************************/
int open_adc(const char *adc)
{
	if (!adc) {
		return -1;
	}

	adc_fd = open(adc, O_RDONLY);
	if (adc_fd < 0) {
		perror("Open adc device faild");
		return -1;
	}

	printf("Open adc device success:%s\n", adc);

	return adc_fd;
}

/************************************************************
 * read_adc:
 *     Read adc value from read_fd at channel
 *
 *   read_fd: the discription of the readed adc
 *   channel: the read channel
 ***********************************************************/
int read_adc(const int read_fd, const int channel)
{
	int retval;

	retval = ioctl(read_fd, ADC_READ, channel);
	if (retval <  0) {
		perror("Read adc value error");
	}

	return retval;
}

int main(int argc, char *argv[])
{
	int channel = 6;
	int adc_val;
	char buf[6];
	
	open_adc(ADC_DEV);

	if (adc_fd < 0) {
		perror("Open adc fail");
		return 1;
	} else {
		printf("Adc file description: %d\n", adc_fd);
	}

	if (argc > 1) {
		channel = argv[1][0] - '0';
	}
	
	while (1) {
		adc_val = read_adc(adc_fd, channel);
		if (adc_val > -1) {
			printf("ADC value on %d channel: %d\n", channel, adc_val);
		}
			
		sleep(1);
	}
	
	return 0;
}
